WaitingPage.responsive_width — alfred3_interact

Skip to main content
`Ctrl`+`K`

# WaitingPage.responsive_width

property WaitingPage.responsive_width

  Custom values for definig the width of the page in percent of the screen width. Only takes effect, if the option responsive in section layout is “true” (which is the default). Must be a single string with 1 to 5 relative widths separated by commas, e.g. “60%, 50%”. The first value refers to extra small (‘xs’) screens, the following values to the next bigger ones. If the string contains less than five values, the last value will be used for all screens from that size on upward.

  The sizes are taken from Bootstrap and correspond to the five width attributes of a `RowLayout`.

  Can be defined as a class attribute.